@@ -178,6 +178,34 @@ class Update:
                 manager_user_id = self.scim_users[manager_email]["id"]
         return manager_user_id
 
+    def _get_people(self):
+        """Return a dict of people from BITSdb."""
+        collection = "people_people"
+        project = "broad-bitsdb-firestore"
+        g = self.auth.google()
+        firestore = g.firestore(project)
+        people = {}
+        self.emplids = {}
+        for person in firestore.get_collection(collection):
+            emplid = person["emplid"]
+            self.emplids[emplid] = person
+            key = person["email_username"]
+            if not key:
+                continue
+            key = key.lower()
+            if key in people:
+                print(f"ERROR: Duplicate email in people: {key}")
+                continue
+            people[key] = person
+        return people
+
+    def _get_pronouns_suffix(self, last_name):
+        """Return the pronouns suffix for the given last name."""
+        suffix = ""
+        if last_name and re.search(r"\(.*/.*\)$", last_name):
+            suffix = re.sub(r".* (\(.*/.*\))$", r"\1", last_name).replace(" ", "")
+        return suffix
+
     def _get_other_accounts(self):
         """Return a dict of other accounts from BITSdb."""
         mongo = self.auth.mongo()
@@ -234,33 +262,33 @@ class Update:
             syncs.append(sync)
         return syncs
 
-    def _get_people(self):
-        """Return a dict of people from BITSdb."""
-        collection = "people_people"
-        project = "broad-bitsdb-firestore"
-        g = self.auth.google()
-        firestore = g.firestore(project)
-        people = {}
-        self.emplids = {}
-        for person in firestore.get_collection(collection):
-            emplid = person["emplid"]
-            self.emplids[emplid] = person
-            key = person["email_username"]
-            if not key:
-                continue
-            key = key.lower()
-            if key in people:
-                print(f"ERROR: Duplicate email in people: {key}")
-                continue
-            people[key] = person
-        return people
+    def _get_sync_group_emails(self):
+        """Return a list of Google Group emails to sync."""
+        emails = [
+            "activebroadies@broadinstitute.org",
+        ]
 
-    def _get_pronouns_suffix(self, last_name):
-        """Return the pronouns suffix for the given last name."""
-        suffix = ""
-        if last_name and re.search(r"\(.*/.*\)$", last_name):
-            suffix = re.sub(r".* (\(.*/.*\))$", r"\1", last_name).replace(" ", "")
-        return suffix
+        if self.verbose:
+            print("Getting Slack Usergroups Syncs from BITSdb Mongo DB...")
+        syncs = self._get_slack_usergroup_syncs()
+        if self.verbose:
+            print(f"Usergroup Sync: {len(syncs)}")
+
+        # create missing groups and update groups
+        for sync in sorted(syncs, key=lambda x: x["google_group"]):
+
+            # get google group email
+            email = sync["google_group"].lower()
+            if not email.endswith("@broadinstitute.org"):
+                print(f"Skipping non-Broad group: {email}")
+                continue
+
+            if email not in emails:
+                emails.append(email)
+            else:
+                print(f"Warning: Duplicate Sync Email: {email}")
+
+        return emails
 
     def _prepare_idp_user(self, person):
         """Prepare a user for the Slack IDP."""
@@ -307,12 +335,6 @@ class Update:
         """Update the IDP Groups in Slack Enterprise Grid."""
         scim = SCIM(self.slack.token)
 
-        if self.verbose:
-            print("Getting Slack Usergroups Syncs from BITSdb Mongo DB...")
-        syncs = self._get_slack_usergroup_syncs()
-        if self.verbose:
-            print(f"Usergroup Sync: {len(syncs)}")
-
         if self.verbose:
             print("Getting Slack Groups from SCIM API...")
         groups = scim.get_groups_dict()
@@ -327,23 +349,18 @@ class Update:
 
         self.google_users = self._get_google_users()
 
-        sync_groups = []
+        google_group_emails = self._get_sync_group_emails()
 
         # create missing groups and update groups
-        for sync in sorted(syncs, key=lambda x: x["google_group"]):
+        for google_group_email in google_group_emails:
 
             # get google group email
-            google_group_email = sync["google_group"]
             if not google_group_email.endswith("@broadinstitute.org"):
                 print(f"Skipping non-Broad group: {google_group_email}")
                 continue
 
             name = google_group_email.replace("@broadinstitute.org", "")
 
-            if name in sync_groups:
-                print(f"Duplicate sync group: {name}")
-                continue
-
             # get google group members
             google_group_members = self._get_google_group_emails(google_group_email)
 
@@ -376,14 +393,13 @@ class Update:
                     group["members"] = members
                     scim.update_group(group["id"], group)
 
-            sync_groups.append(name)
-
         # find groups to delete
         for name in groups:
+            email = f"{name}@broadinstitute.org"
             group = groups[name]
-            if name not in sync_groups:
+            if email not in google_group_emails:
                 print(f"Deleting group: {name}")
-                scim.delete_group(group.id)
+                scim.delete_group(group["id"])
 
     def idp_users(self):
         """Update IDP users in Slack."""
